# Copy this file to ~/.config/fish/completions
complete -c ugrep-indexer -l accuracy -s 0 -s 1 -s 2 -s 3 -s 4 -s 5 -s 6 -s 7 -s 8 -s 9 -d 'Specifies indexing accuracy'
complete -c ugrep-indexer -l hidden -s '.' -d 'Index hidden files and directories'
complete -c ugrep-indexer -l help -s '?' -d 'Display a help message and exit'
complete -c ugrep-indexer -s c -l check -d 'Recursively check and report indexes without reindexing files'
complete -c ugrep-indexer -s d -l delete -d 'Recursively remove index files'
complete -c ugrep-indexer -s f -l force -d 'Force reindexing of files, even those that are already indexed'
complete -c ugrep-indexer -s I -l ignore-binary -d 'Do not index binary files'
complete -c ugrep-indexer -s q -l quiet -l silent -d 'Quiet mode: do not display indexing statistics'
complete -c ugrep-indexer -s S -l dereference-files -d 'Follow symbolic links to files'
complete -c ugrep-indexer -s s -l no-messages -d 'Silent mode: nonexistent and unreadable files are ignored, i.e. their error messages and warnings are suppressed'
complete -c ugrep-indexer -s V -l version -d 'Display version and exit'
complete -c ugrep-indexer -s v -l verbose -d 'Produce verbose output'
complete -c ugrep-indexer -s X -l ignore-files -d 'Do not index files and directories matching the globs in FILE encountered during indexing'
complete -c ugrep-indexer -s z -l decompress -d 'Index the contents of compressed files and archives'
complete -c ugrep-indexer -l zmax -d 'When used with option -z (--decompress), indexes the contents of compressed files and archives stored within archives by up to NUM expansion levels deep'
